clear;
close all;
clc;

disp('nScope Pong!');
disp('  You must score at least 25 points in 40s to win');
disp('  Collecting voltage from Ch1 at 50Hz...');

playtime = 40; % in seconds
numSamples = playtime*50; % collected at 50 hz

figure();
ballx = 100;
bally = randi([1,4]);
balldir = 1;
dy = (rand - 0.5)/4;
score = 0;
paddle = 2.5;
prevpaddle = 2.5;
scoretime = 0;

nScopeAPI('open',1);
disp('  nScope opened...');

nScopeAPI('setChannelsOn',1,0,0,0);         % turn on Channel 1, and no others
nScopeAPI('setCh1gain',1);                  % set the gain on Channel 1
nScopeAPI('setSampleRateInHz',50);          % set the sample rate
nScopeAPI('requestData', numSamples);       % request the samples from nScope

data = zeros(numSamples+800,1);
trace = zeros(400,1);
i = 400;
tic;
while(nScopeAPI('requestHasData'))
    i=i+1;
    data(i) = nScopeAPI('readData',1);
        
    paddle = data(i);
    ballx = ballx + balldir*3;
    bally = bally + dy;

    % ball escapes the paddle
    if (ballx > 390)
        ballx = 100;
        bally = randi([1,4]);
        balldir = 1;
        dy = (rand - 0.5)/4;
        score = score - 10;
    end

    % is the ball on the paddle
    if((ballx > 350)&&(ballx < 400)&&(bally > paddle-.5)&&(bally < paddle + .5))
        if toc > scoretime + 1
            score = score + 5;
            scoretime = toc;
            balldir = balldir * -1;
            if paddle > prevpaddle
                dy = paddle - prevpaddle;
                if dy > 2
                    dy = 2;
                end
                if dy < -2
                    dy = -2;
                end
            end
        end
    end

    % switch direction if hit back wall
    if ((ballx < 10)&&(balldir == -1))
        balldir = balldir * -1;
    end

    % switch direction if hit the vertical
    if bally > 4.5
        dy = dy * -1;
    end
    if bally < 0.5
        dy = dy * -1;
    end

    prevpaddle = paddle;
        
    clf;
    hold on;
    trace = data(i-399:i);
    plot(1:400,trace,'k:');
    plot(ballx,bally,'.','MarkerSize',72);
    plot(399,paddle,'s','MarkerSize',72);
    text(20,5,['Score = ' num2str(score)]);
    t = toc;
    text(20,4.75,['Time = ' num2str(t)]);
    axis([0 400 -0.5 5.5]);
    pause(0.001);
end

if (score >= 25)
    text(200,2.5,'You win!');
else
	text(200,2.5,'Try again!');
end

disp('  Collection Complete!');

nScopeAPI('close');